from prsmsp.panel import Panel

__author__ = "Parsa Riyahi"
__email__ = "pany.parsariyahi@gmail.com"

__version__ = "1.7.1"
